<?php
/**
 * Plugin Name: Amber Alert
 * Plugin URI: https://php-globe.nl/wordpress_plugin/amber-alert
 * Description: Display dutch amber alerts when the are active
 * Version: 1.2.1
 * Text Domain: amber-alert
 * Author: Johan Wiegel @ PHP-GLOBE
 * Author URI: https://php-globe.nl
 * Since: 20210205
 */

add_action('init', 'register_amber_alert_shortcode');

function register_amber_alert_shortcode()
{
    add_shortcode('amber-alert', 'amber_alert');
}

function amber_alert($aArgs = array())
{
    extract(shortcode_atts(array(
        'nl' => 'true',
        'vermist' => 'true',
        'popup' => 'true',
        'debug' => 'true'
    ), $aArgs));

    $sHTML = '';

    $aFeeds = array();
    if( $nl  == 'true' )
    {
        $aFeeds[] = 'NL';
    }
    if( $vermist == 'true' )
    {
        $aFeeds[] = 'VERMIST';
    }

    $iCounter = 1;
    foreach( $aFeeds AS $feed )
    {
        switch ($feed)
        {
            case 'NL':
                $rss = 'https://alert.amberalert.nl/nl/rssext.xml';
                $sClass = 'amber-alert-border';
                $sTitel = 'Amber alert';
                break;

            case 'EU':
                $rss = 'http://feed.amberalert.eu/rssext.xml';
                $sClass = 'amber-alert-border';
                $sTitel = 'Amber alert';
                break;

            case 'VERMIST':
                $rss = 'https://missing.amberalert.nl/nl/index.rss';
                $sClass = 'missing-kids-border';
                $sTitel = 'Vermist kind alert';
                break;

            default:
                $rss = 'https://alert.amberalert.nl/nl/rssext.xml';
                $sClass = 'amber-alert-border';
                $sTitel = 'Amber alert';
                break;
        }

        if ($debug == 'true')
        {
            $sXML = file_get_contents(__DIR__ . '/rss/test-alert-' . $feed . '.xml');
        }
        else
        {
            $sXML = file_get_contents($rss);
        }

        $xml = simplexml_load_string($sXML);

        $xml->registerXPathNamespace('np', 'http://netpresenter.com/');

        if( count( $xml->channel->item ) > 0 )
        {
            if ($popup == 'true' AND $iCounter == 1 )
            {
                $sHTML .= '<div class="amber-alert-popup">';
                $iCounter++;
            }
        }

        foreach ($xml->channel->item as $oItem)
        {
            if (!isset($_COOKIE['amber-alert']) or $_COOKIE['amber-alert'] <> $oItem->guid)
            {
                $sHTML .= '<div class="amber-alert ' . $sClass . '">';

                $img = $xml->xpath('//np:image');

                foreach ($img as $oImg)
                {
                    $sHTML .= '<img src="' . $oImg[0][0] . '" class="amber-alert-image" />';
                    break;
                }

                $sHTML .= '<h3>' . $sTitel . '</h3>
                   <h4>' . $oItem->title . '</h4>
                   <div class="amber-alert-description">
                   ' . nl2br($oItem->description) . '<br/>';

                $sHTML .= '<p><a href="' . $oItem->link . '" target="_blank">Meer info ' . $oItem->image . '</a></p>';
                if ($popup == 'true')
                {
                    $sHTML .= '<p><a id="amber-alert-dismiss" data-amber-alert="' . $oItem->guid . '">' . __('Laat deze alert niet meer zien.') . '</a></p>';
                }
                $sHTML .= '</div>';
                $sHTML .= '</div>';
            }
        }

    }

    if( $sHTML <> '' AND $popup == 'true' )
    {
        $sHTML .= '</div>';
    }
    return ( $sHTML );
}

function amber_alert_load_plugin_css()
{
    $plugin_url = plugin_dir_url(__FILE__);

    wp_enqueue_style('amber-alert', $plugin_url . 'css/amber-alert.css');

}

add_action('wp_enqueue_scripts', 'amber_alert_load_plugin_css');

function amber_alert_load_jquery()
{
    if (!wp_script_is('jquery', 'enqueued'))
    {
        //Enqueue
        wp_enqueue_script('jquery');
    }
}

add_action('wp_enqueue_scripts', 'amber_alert_load_jquery');

/**
 * Custom JS for closing and setting cookie
 */

add_action('wp_enqueue_scripts', 'amber_alert_script_load');
function amber_alert_script_load()
{
    $plugin_url = plugin_dir_url(__FILE__);
    wp_enqueue_script('amber-alert-script', $plugin_url . 'js/amber-alert.js', array('jquery'));
}


/** WIDGET **/
// Creating the widget
class amber_alert_widget extends WP_Widget
{

    function __construct()
    {
        parent::__construct(

        // Base ID of your widget
            'amber_alert_widget',

            // Widget name will appear in UI
            __('Amber Alert Widget', 'amber_alert_widget_domain'),

            // Widget description
            array('description' => __('Amber Alert Widget', 'amber_alert_widget_domain'),),
            array(),
            array('debug', 'popup' => 'true', 'nl', 'vermist')
        );
    }

    // Creating widget front-end

    public function widget($args, $instance)
    {
        // before and after widget arguments are defined by themes
        echo $args['before_widget'];

        // This is where you run the code and display the output
        $aArgs = array();
        $aArgs['debug'] = $instance['debug'] ? 'true' : 'false';
        $aArgs['popup'] = $instance['popup'] ? 'true' : 'false';
        $aArgs['nl'] = $instance['nl'] ? 'true' : 'false';
        $aArgs['vermist'] = $instance['vermist'] ? 'true' : 'false';

        echo amber_alert( $aArgs );
        echo $args['after_widget'];
    }

    // Widget Backend
    public function form($instance)
    {
        // Settings in Widget
        $defaults = array( 'debug' => 'off', 'popup' => 'on', 'nl' => 'on', 'vermist' => 'on' );
        $instance = wp_parse_args( ( array ) $instance, $defaults );
        ?>
        <p>
            <input class="checkbox" type="checkbox" <?php checked($instance['debug'], 'on'); ?>
                   id="<?php echo $this->get_field_id('debug'); ?>"
                   name="<?php echo $this->get_field_name('debug'); ?>"/>
            <label for="<?php echo $this->get_field_id('debug'); ?>"><?php echo __('Gebruik lokaal test bestand');?></label>
        </p>
        <p>
            <input class="checkbox" type="checkbox" <?php checked($instance['popup'], 'on'); ?>
                   id="<?php echo $this->get_field_id('popup'); ?>"
                   name="<?php echo $this->get_field_name('popup'); ?>"/>
            <label for="<?php echo $this->get_field_id('popup'); ?>"><?php echo __('Alert tonen als popup');?></label>
        </p>
        <p>
            <input class="checkbox" type="checkbox" <?php checked($instance['nl'], 'on'); ?>
                   id="<?php echo $this->get_field_id('nl'); ?>"
                   name="<?php echo $this->get_field_name('nl'); ?>"/>
            <label for="<?php echo $this->get_field_id('nl'); ?>"><?php echo __('Amber Alert NL tonen indien actief');?></label>
        </p>
        <p>
            <input class="checkbox" type="checkbox" <?php checked($instance['vermist'], 'on'); ?>
                   id="<?php echo $this->get_field_id('vermist'); ?>"
                   name="<?php echo $this->get_field_name('vermist'); ?>"/>
            <label for="<?php echo $this->get_field_id('vermist'); ?>"><?php echo __('Vermiste kinderen alert tonen indien actief');?></label>
        </p>


        <?php
    }

    // Updating widget replacing old instances with new
    public function update($new_instance, $old_instance)
    {
        $instance = array();
        $instance['debug'] = $new_instance['debug'];
        $instance['popup'] = $new_instance['popup'];
        $instance['nl'] = $new_instance['nl'];
        $instance['vermist'] = $new_instance['vermist'];
        return $instance;
    }

}

// Register and load the widget
function amber_alert_load_widget()
{
    register_widget('amber_alert_widget');
}

add_action('widgets_init', 'amber_alert_load_widget');

/** END WIDGET **/

register_uninstall_hook(__FILE__, 'amber_alert_uninstall');

function amber_alert_uninstall()
{
    $sRole = get_role('administrator');
    if (!empty($sRole))
    {
    }
}

/**
 * Update checker
 */
require dirname(__FILE__) . '/plugin-update-checker/plugin-update-checker.php';
$MyUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
    'https://php-globe.nl/wp-update-server/?action=get_metadata&slug=amber-alert', //Metadata URL.
    __FILE__, //Full path to the main plugin file.
    'amber-alert' //Plugin slug. Usually it's the same as the name of the directory.
);